# Sources
- List of Muslim first names and counts extracted from [https://nors.ku.dk/publikationer/webpublikationer/muslimske_fornavne/](https://nors.ku.dk/publikationer/webpublikationer/muslimske_fornavne/)
- List of Muslim last names taken from [https://www.familyeducation.com/baby-names/browse-origin/surname/muslim](https://www.familyeducation.com/baby-names/browse-origin/surname/muslim)
- List of Danish first and last names and counts taken from [http://www.danskernesnavne.navneforskning.ku.dk/TopNavne.asp](http://www.danskernesnavne.navneforskning.ku.dk/TopNavne.asp)